<template>
    <div class="notice">
        <el-dialog
            v-model="dialogVisible"
            :title="title"
            width="500px"
            :before-close="handleClose"
        >
            <el-form :model="state.form" size="default" ref="busRef" :rules="state.formRules" label-position="top">
                <el-form-item label="设备名称:" prop="deviceName">
                  <el-input v-model.trim="state.form.deviceName" maxlength="30" show-word-limit type="text" size="large"/>
                </el-form-item>
                <el-form-item label="开始时间:" prop="startDate">
                  <el-date-picker
                      style="width: 100%"
                      v-model="state.form.startDate"
                      type="date"
                      value-format="YYYY-MM-DD 00:00:00"
                      placeholder="选择日期"
                      size="large"
                  />
                </el-form-item>
                <el-form-item label="结束时间:" prop="endDate">
                  <el-date-picker
                      style="width: 100%"
                      v-model="state.form.endDate"
                      type="date"
                      value-format="YYYY-MM-DD 00:00:00"
                      placeholder="选择日期"
                      size="large"
                  />
                </el-form-item>
            </el-form>
            <template #footer>
                    <span class="dialog-footer">
                        <el-button @click="handleClose" size="default">取 消</el-button>
                        <el-button type="primary"  @click="onSubmit" size="default" v-preReClick>确认</el-button>
                    </span>
            </template>
        </el-dialog>
    </div>
</template>
<script setup>
import {defineProps, nextTick, reactive, ref, toRefs} from 'vue'
import {ElMessage} from "element-plus";
import {addDevice, editDevice} from "@/api/projectManage/evaPlan"
const dialogVisible = ref(false)
const title = ref("")
const busRef = ref()
const props = defineProps(['workList','typeList'])
const emit = defineEmits(["getList"])
const state = reactive({
    form: {
      id: null,
      projectId: null,
      deviceName: '',
      startDate: '',
      endDate: ''
    },
    formRules:{
      deviceName: [{ required: true, message: '请填写设备名称', trigger: 'blur' }],
      startDate: [{ required: true, message: '请选择开始日期', trigger: 'blur' }],
      endDate: [{ required: true, message: '请选择结束日期', trigger: 'blur' }]
    }
})

const openDialog = async (type, value,projectId) => {
    title.value = type === 'add' ? '新增' : type ==='edit' ? '编辑' : '查看'
    state.form.projectId = projectId
    if(type == 'add'){
      nextTick(()=>{
        busRef.value.resetFields()
      })
    }else if(type === 'edit') {
      state.form = JSON.parse(JSON.stringify(value))
    }
    dialogVisible.value = true;
}

const onSubmit = async () => {
    const valid = await busRef.value.validate();
    if(valid){
        if(title.value === '新增'){
            const {id,...data} = state.form
            const res = await addDevice(data)
            if(res.code === 200){
                ElMessage({
                    type: 'success',
                    message: '新增成功'
                });
            }else{
                ElMessage.warning(res.message)
            }
            emit("getList")
            busRef.value.clearValidate();
            busRef.value.resetFields()
            dialogVisible.value = false;
        }else if(title.value === '编辑'){
            const {...data} = state.form
            const res = await editDevice(data)
            if(res.code === 200){
                ElMessage({
                    type: 'success',
                    message: '修改成功'
                });
            }else{
                ElMessage.warning(res.message)
            }
            emit("getList")
            busRef.value.clearValidate();
            busRef.value.resetFields()
            dialogVisible.value = false;
        }
    }
}

const handleClose = () => {
    busRef.value.clearValidate();
    busRef.value.resetFields()
    dialogVisible.value = false;
}

defineExpose({
    openDialog
});

</script>

<style scoped lang="scss">
.notice{
    :deep(.el-form .el-form-item__label) {
        font-size: 15px;
    }
    .file {
        display: flex;
        flex-direction: column;
        align-items: flex-start;
    }
}
</style>
